@@ -853,8 +853,8 @@ def list_elements(include_priority=False):
     dataframe IF include_priority = True
     '''
 
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Element_Reader.xlsx')
     els = pd.read_excel(FILE)
 
     if include_priority == True:
@@ -867,20 +867,20 @@ def list_elements(include_priority=False):
 
 
 def return_NSSPElementReader():
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_tryme.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Element_Reader.xlsx')
     reader = pd.read_excel(FILE)
     return reader
 
 def return_NSSPValidityReader():
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Validity_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Validity_Reader.xlsx')
     reader = pd.read_excel(FILE)
     return reader
 
 def return_MessageCorrectorKey():
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/Message_Corrector_Key.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/Message_Corrector_Key.xlsx')
     reader = pd.read_excel(FILE)
     return reader
 
@@ -944,8 +944,8 @@ def NSSP_Element_Grabber(data,explicit_search=None,Priority_only=False,outfile='
     
     # Read in reader file as pandas dataframe
 
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Element_Reader.xlsx')
     reader = pd.read_excel(FILE)
     
     if explicit_search != None:
@@ -1084,8 +1084,8 @@ def priority_cols(df, priority='both', extras=None, drop_cols=None):
     -import pandas as pd
     '''
 
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Element_Reader.xlsx')
     reader = pd.read_excel(FILE)
 
 
@@ -1171,8 +1171,8 @@ def validity_check(df, Timed=True):
     
     # Read in the validity key
 
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Validity_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Validity_Reader.xlsx')
     key = pd.read_excel(FILE)
 
     # There is a chance that the user had decided to get rid of columns we typically check for validity.
@@ -1287,8 +1287,8 @@ def Visualize_Facility_DQ(df, fac_name, hide_yticks = False, Timed = True):
     hosp_visits = df[df.FACILITY_NAME==fac_name]
 
     # Read in our validity key
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Validity_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Validity_Reader.xlsx')
     key = pd.read_excel(FILE)
 
     # There is a chance that the user had decided to get rid of columns we typically check for validity.
@@ -1572,8 +1572,8 @@ def issues_in_messages(df, Timed=True, combine_issues_on_message = False, split_
     ########################################################################################################
 
     # Load our key and set its index
-    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/Message_Corrector_Key.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+    FILE = pkg_resources.resource_filename('ADTdq', 'supporting/Message_Corrector_Key.xlsx')
     key = pd.read_excel(FILE)
 
     key = key.set_index('Element')
@@ -1892,8 +1892,8 @@ def validity_and_completeness_report(df,description='long',visit_count=False,out
 
     if description == 'long':
 
-        DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-        FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/Message_Corrector_Key.xlsx')
+        DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+        FILE = pkg_resources.resource_filename('ADTdq', 'supporting/Message_Corrector_Key.xlsx')
         key = pd.read_excel(FILE)
 
 
@@ -1904,8 +1904,8 @@ def validity_and_completeness_report(df,description='long',visit_count=False,out
 
     elif description == 'short':
 
-        DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
-        FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+        DATA_PATH = pkg_resources.resource_filename('ADTdq', 'supporting/')
+        FILE = pkg_resources.resource_filename('ADTdq', 'supporting/NSSP_Element_Reader.xlsx')
         key = pd.read_excel(FILE)
 
         key = key.set_index('Processed Column')
